/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class KafkaStoreMessageHandler
    implements StoreUpdateHandler<SecretRegistryKey, SecretRegistryValue> {

  private static final Logger log = LoggerFactory.getLogger(KafkaStoreMessageHandler.class);
  private final KafkaSecretRegistry secretRegistry;
  private final LookupCache<SecretRegistryKey, SecretRegistryValue> lookupCache;

  public KafkaStoreMessageHandler(
      KafkaSecretRegistry secretRegistry,
      LookupCache<SecretRegistryKey, SecretRegistryValue> lookupCache
  ) {
    this.secretRegistry = secretRegistry;
    this.lookupCache = lookupCache;
  }

  /**
   * Invoked before every new K,V pair written to the store
   *
   * @param key   Key associated with the data
   * @param value Data written to the store
   */
  public boolean validateUpdate(SecretRegistryKey key, SecretRegistryValue value) {
    return true;
  }

  /**
   * Invoked on every new secret written to the Kafka store
   *
   * @param key   Key associated with the secret.
   * @param value Value written to the Kafka lookupCache
   */
  @Override
  public void handleUpdate(SecretRegistryKey key, SecretRegistryValue value) {
  }
}
