/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

import java.util.List;
import java.util.Set;

import io.confluent.kafka.secretregistry.client.rest.entities.Secret;
import io.confluent.kafka.secretregistry.exceptions.SecretRegistryException;
import io.confluent.kafka.secretregistry.rest.SecretRegistryConfig;
import io.confluent.kafka.secretregistry.rest.SslFactory;

public interface SecretRegistry {

  void initStore() throws SecretRegistryException;

  void initRest(SslFactory sslFactory, UriInfo uriInfo) throws SecretRegistryException;

  SecretRegistryConfig config();

  int register(Secret secret) throws SecretRegistryException;

  Set<String> listPaths() throws SecretRegistryException;

  Set<String> listKeys(String path) throws SecretRegistryException;

  List<Integer> listVersions(String path, String key) throws SecretRegistryException;

  List<Secret> getAllLatest(String path)
      throws SecretRegistryException;

  List<Secret> getAllVersions(String path, String key)
      throws SecretRegistryException;

  Secret getLatestVersion(String path, String key) throws SecretRegistryException;

  Secret get(String path, String key, int version)
      throws SecretRegistryException;

  Set<String> deletePath(String path) throws SecretRegistryException;

  List<Integer> deleteKey(String path, String key) throws SecretRegistryException;

  void deleteVersion(String path, String key, int version) throws SecretRegistryException;

  void close();

}
